==> openapi-rapi-domain-0.0.188-sources.jar: com/xforceplus/openapirapi/dict/InvoiceFrom.java <==
package com.xforceplus.openapirapi.dict;

import com.baomidou.mybatisplus.annotation.EnumValue;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * <p>
 * 发票来源
 * </p>
 *
 * @author ultraman
 * @since 2023-04-19
 */
public enum InvoiceFrom {

    SALES_V4("SALES_V4", "4.0 销项"),
    PURCHASE_V4("PURCHASE_V4", "4.0 进项"),
    SALES_V3("SALES_V3", "3.0 销项"),
    PURCHASE_V3("PURCHASE_V3", "3.0 进项"),
    TAXWARE_LF("TAXWARE_LF", "税件发票低频"),
    TAXWARE_CO("TAXWARE_CO", "税件发票归集"),
    IMAGE("IMAGE", "电子影像"),
    PURCHASE_V5("PURCHASE_V5", "4.0 进项（新）"),
    PURCHASE_V4_VERIFY("PURCHASE_V4_VERIFY", "4.0 进项验真");

    @EnumValue
    @JsonValue
    private final String code;

    private final String desc;

    public String getCode(){
        return this.code;
    }

    public String getDesc(){
        return this.desc;
    }

    InvoiceFrom(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    @Override
    public String toString() {
        return this.code;
    }

    public static InvoiceFrom fromCode(String code){
        switch(code) {
            case "SALES_V4":
                return SALES_V4;
            case "PURCHASE_V4":
                return PURCHASE_V4;
            case "SALES_V3":
                return SALES_V3;
            case "PURCHASE_V3":
                return PURCHASE_V3;
            case "TAXWARE_LF":
                return TAXWARE_LF;
            case "TAXWARE_CO":
                return TAXWARE_CO;
            case "IMAGE":
                return IMAGE;
            case "PURCHASE_V5":
                return PURCHASE_V5;
            case "PURCHASE_V4_VERIFY":
                return PURCHASE_V4_VERIFY;
            default:
                return null;
        }
    }
}

==> openapi-rapi-domain-0.0.276-sources.jar: com/xforceplus/openapirapi/dict/InvoiceFrom.java <==
package com.xforceplus.openapirapi.dict;

import com.baomidou.mybatisplus.annotation.EnumValue;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * <p>
 * 发票来源
 * </p>
 *
 * @author ultraman
 * @since 2023-07-13
 */
public enum InvoiceFrom {

    SALES_V4("SALES_V4", "4.0 销项"),
    PURCHASE_V4("PURCHASE_V4", "4.0 进项"),
    SALES_V3("SALES_V3", "3.0 销项"),
    PURCHASE_V3("PURCHASE_V3", "3.0 进项"),
    TAXWARE_LF("TAXWARE_LF", "税件发票低频"),
    TAXWARE_CO("TAXWARE_CO", "税件发票归集"),
    IMAGE("IMAGE", "电子影像"),
    PURCHASE_V5("PURCHASE_V5", "4.0 进项（新）"),
    PURCHASE_V4_VERIFY("PURCHASE_V4_VERIFY", "4.0 进项验真"),
    LEDGER("LEDGER", "底账");

    @EnumValue
    @JsonValue
    private final String code;

    private final String desc;

    public String getCode(){
        return this.code;
    }

    public String getDesc(){
        return this.desc;
    }

    InvoiceFrom(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    @Override
    public String toString() {
        return this.code;
    }

    public static InvoiceFrom fromCode(String code){
        switch(code) {
            case "SALES_V4":
                return SALES_V4;
            case "PURCHASE_V4":
                return PURCHASE_V4;
            case "SALES_V3":
                return SALES_V3;
            case "PURCHASE_V3":
                return PURCHASE_V3;
            case "TAXWARE_LF":
                return TAXWARE_LF;
            case "TAXWARE_CO":
                return TAXWARE_CO;
            case "IMAGE":
                return IMAGE;
            case "PURCHASE_V5":
                return PURCHASE_V5;
            case "PURCHASE_V4_VERIFY":
                return PURCHASE_V4_VERIFY;
            case "LEDGER":
                return LEDGER;
            default:
                return null;
        }
    }
}
